@@ -1,4 +1,4 @@
 from __future__ import absolute_import
 from .extractor import *
 
-name = "extractor"
\ No newline at end of file
+name = "article_extractor"
